from typing import overload
from typing import List
from typing import TypeVar
from .PerExecLibrary import PerExecLibrary
from .BaseScriptContext import BaseScriptContext
from .FileHandler import FileHandler
from .MethodWrapper import MethodWrapper

java_io_File = TypeVar("java_io_File")
File = java_io_File


class FFS(PerExecLibrary):
	"""Better File-System functions. 
An instance of this class is passed to scripts as the 'FS' variable.\n
	Since: 1.1.8 
	"""

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def list(self, path: str) -> List[str]:
		"""List files in path.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			An array of file names as String . 
		"""
		pass

	@overload
	def exists(self, path: str) -> bool:
		"""Check if a file exists.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 
		"""
		pass

	@overload
	def isDir(self, path: str) -> bool:
		"""Check if a file is a directory.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 
		"""
		pass

	@overload
	def isFile(self, path: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			path: the path relative to the script's folder 

		Returns:
			'true' if the path leads to a file, 'false' otherwise. 
		"""
		pass

	@overload
	def getName(self, path: str) -> str:
		"""Get the last part (name) of a file.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a String of the file name. 
		"""
		pass

	@overload
	def toRelativePath(self, absolutePath: str) -> str:
		"""
		Since: 1.8.4 

		Args:
			absolutePath: the absolute path to the file 

		Returns:
			a path relative to the script's folder to the given absolute path. 
		"""
		pass

	@overload
	def createFile(self, path: str, name: str) -> bool:
		"""Creates a new file in the specified path, relative to the script's folder. This will only
work if the parent directory already exists. See FFS#createFile(java.lang.String,java.lang.String,boolean) to automatically create all parent directories.\n
		Since: 1.8.4 

		Args:
			path: the path relative to the script's folder 
			name: the name of the file 

		Returns:
			'true' if the file was created successfully, 'false' otherwise. 
		"""
		pass

	@overload
	def createFile(self, path: str, name: str, createDirs: bool) -> bool:
		"""Creates a new file in the specified path, relative to the script's folder. Optionally parent
directories can be created if they do not exist.\n
		Since: 1.8.4 

		Args:
			path: the path relative to the script's folder 
			createDirs: whether to create parent directories if they do not exist or not 
			name: the name of the file 

		Returns:
			'true' if the file was created successfully, 'false' otherwise. 
		"""
		pass

	@overload
	def makeDir(self, path: str) -> bool:
		"""Make a directory.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a Boolean for success. 
		"""
		pass

	@overload
	def move(self, from_: str, to: str) -> None:
		"""Move a file.\n
		Since: 1.1.8 

		Args:
			from: relative to the script's folder. 
			to: relative to the script's folder. 
		"""
		pass

	@overload
	def copy(self, from_: str, to: str) -> None:
		"""Copy a file.\n
		Since: 1.1.8 

		Args:
			from: relative to the script's folder. 
			to: relative to the script's folder. 
		"""
		pass

	@overload
	def unlink(self, path: str) -> bool:
		"""Delete a file.\n
		Since: 1.2.9 

		Args:
			path: relative to the script's folder. 

		Returns:
			a Boolean for success. 
		"""
		pass

	@overload
	def combine(self, patha: str, pathb: str) -> str:
		"""Combine 2 paths.\n
		Since: 1.1.8 

		Args:
			patha: path is relative to the script's folder. 
			pathb: 

		Returns:
			a String of the combined path. 
		"""
		pass

	@overload
	def getDir(self, path: str) -> str:
		"""Gets the directory part of a file path, or the parent directory of a folder.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a String of the combined path. 
		"""
		pass

	@overload
	def open(self, path: str) -> FileHandler:
		"""Open a FileHandler for the file at the specified path.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a FileHandler for the file path. 
		"""
		pass

	@overload
	def open(self, path: str, charset: str) -> FileHandler:
		"""Open a FileHandler for the file at the specified path.\n
		Since: 1.8.4 

		Args:
			path: relative to the script's folder. 
			charset: the charset to use for reading/writing the file (default is UTF-8) 

		Returns:
			a FileHandler for the file path. 
		"""
		pass

	@overload
	def walkFiles(self, path: str, maxDepth: int, followLinks: bool, visitor: MethodWrapper) -> None:
		"""An advanced method to walk a directory tree and get some information about the files, as well
as their paths.\n
		Since: 1.8.4 

		Args:
			maxDepth: the maximum depth to follow, can cause stack overflow if too high 
			path: the relative path of the directory to walk through 
			followLinks: whether to follow symbolic links 
			visitor: the visitor that is called for each file with the path of the file and its
                   attributes 
		"""
		pass

	@overload
	def toRawFile(self, path: str) -> File:
		"""
		Since: 1.8.4 

		Args:
			path: the relative path to get the file object for 

		Returns:
			the file object for the specified path. 
		"""
		pass

	@overload
	def toRawPath(self, path: str) -> Path:
		"""
		Since: 1.8.4 

		Args:
			path: the relative path to get the path object for 

		Returns:
			the path object for the specified path. 
		"""
		pass

	@overload
	def getRawAttributes(self, path: str) -> BasicFileAttributes:
		"""
		Since: 1.8.4 

		Args:
			path: the path relative to the script's folder 

		Returns:
			the attributes of the file at the specified path. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper
from .DirectionHelper import DirectionHelper
from .DyeColorHelper import DyeColorHelper

net_minecraft_entity_mob_ShulkerEntity = TypeVar("net_minecraft_entity_mob_ShulkerEntity")
ShulkerEntity = net_minecraft_entity_mob_ShulkerEntity


class ShulkerEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: ShulkerEntity) -> None:
		pass

	@overload
	def isClosed(self) -> bool:
		pass

	@overload
	def getAttachedSide(self) -> DirectionHelper:
		pass

	@overload
	def getColor(self) -> DyeColorHelper:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .BlockHelper import BlockHelper

net_minecraft_entity_vehicle_BoatEntity = TypeVar("net_minecraft_entity_vehicle_BoatEntity")
BoatEntity = net_minecraft_entity_vehicle_BoatEntity


class BoatEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: BoatEntity) -> None:
		pass

	@overload
	def isChestBoat(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the boat is a chest boat, 'false' otherwise. 
		"""
		pass

	@overload
	def getBoatBlockType(self) -> BlockHelper:
		"""
		Since: 1.8.4 

		Returns:
			the boat's plank type. 
		"""
		pass

	@overload
	def getBoatType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the boat's material. 
		"""
		pass

	@overload
	def isInWater(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the boat is on top of water, 'false' otherwise. 
		"""
		pass

	@overload
	def isOnLand(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the boat is on land, 'false' otherwise. 
		"""
		pass

	@overload
	def isUnderwater(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the boat is underwater, 'false' otherwise. 
		"""
		pass

	@overload
	def isInAir(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the boat is in the air, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_entity_decoration_ItemFrameEntity = TypeVar("net_minecraft_entity_decoration_ItemFrameEntity")
ItemFrameEntity = net_minecraft_entity_decoration_ItemFrameEntity


class ItemFrameEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: ItemFrameEntity) -> None:
		pass

	@overload
	def isGlowingFrame(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the item frame is glowing, 'false' otherwise. 
		"""
		pass

	@overload
	def getRotation(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the rotation of the item inside this frame. 
		"""
		pass

	@overload
	def getItem(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item inside this item frame. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IHorseScreen import IHorseScreen

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity


class MixinHorseScreen(IHorseScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getEntity(self) -> Entity:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .ScriptTrigger import ScriptTrigger
from .ServiceTrigger import ServiceTrigger

com_google_gson_JsonObject = TypeVar("com_google_gson_JsonObject")
JsonObject = com_google_gson_JsonObject


class CoreConfigV2:
	maxLockTime: float
	defaultProfile: str
	anythingIgnored: List[str]
	profiles: Mapping[str, List[ScriptTrigger]]
	services: Mapping[str, ServiceTrigger]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getCurrentProfile(self) -> str:
		pass

	@overload
	def setCurrentProfile(self, pname: str) -> None:
		pass

	@overload
	def profileOptions(self) -> List[str]:
		pass

	@overload
	def getEvents(self) -> List[str]:
		pass

	@overload
	def fromV1(self, v1: JsonObject) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_BeeEntity = TypeVar("net_minecraft_entity_passive_BeeEntity")
BeeEntity = net_minecraft_entity_passive_BeeEntity


class BeeEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: BeeEntity) -> None:
		pass

	@overload
	def hasNectar(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the bee has nectar, 'false' otherwise. 
		"""
		pass

	@overload
	def isAngry(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the bee is angry at a player, 'false' otherwise. 
		"""
		pass

	@overload
	def hasStung(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the bee has already stung a player, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .EntityHelper import EntityHelper
from .Vec3D import Vec3D

T = TypeVar("T")

class DisplayEntityHelper(Generic[T], EntityHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def getLerpTargetX(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLerpTargetY(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLerpTargetZ(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLerpTargetPitch(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLerpTargetYaw(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getVisibilityBoundingBox(self) -> Vec3D:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getBillboardMode(self) -> str:
		"""
		Since: 1.9.1 

		Returns:
			"fixed", "vertical", "horizontal" or "center" 
		"""
		pass

	@overload
	def getBrightness(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getSkyBrightness(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getBlockBrightness(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getViewRange(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getShadowRadius(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getShadowStrength(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getDisplayWidth(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getGlowColorOverride(self) -> int:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLerpProgress(self, delta: float) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getDisplayHeight(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

java_util_function_Consumer_java_lang_Integer_ = TypeVar("java_util_function_Consumer_java_lang_Integer_")
Consumer = java_util_function_Consumer_java_lang_Integer_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class SelectorDropdownOverlay(OverlayContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, choices: List[Text], textRenderer: TextRenderer, parent: IOverlayParent, onChoice: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def onScroll(self, page: float) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def setSelected(self, sel: int) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar

net_minecraft_client_input_Input = TypeVar("net_minecraft_client_input_Input")
Input = net_minecraft_client_input_Input


class PlayerInput:
	"""An object, that combines all possible player inputs\n
	Since: 1.4.0 
	"""
	movementForward: float
	movementSideways: float
	yaw: float
	pitch: float
	jumping: bool
	sneaking: bool
	sprinting: bool

	@overload
	def __init__(self) -> None:
		"""Creates a new 'PlayerInput' Object with all values set either to 0 or false\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def __init__(self, movementForward: float, movementSideways: float, yaw: float) -> None:
		"""Creates a new 'PlayerInput' Object with all other values set either to 0 or false\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			yaw: yaw of the player 
			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
		"""
		pass

	@overload
	def __init__(self, movementForward: float, yaw: float, jumping: bool, sprinting: bool) -> None:
		"""Creates a new 'PlayerInput' Object with all other values set either to 0 or false\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			sprinting: sprint input 
			jumping: jump input 
			yaw: yaw of the player 
		"""
		pass

	@overload
	def __init__(self, input: Input, yaw: float, pitch: float, sprinting: bool) -> None:
		"""Creates a new 'PlayerInput' Object from a minecraft input with the missing values extra\n
		Since: 1.4.0 

		Args:
			input: Minecraft Input to be converted. 
			sprinting: sprint input 
			pitch: pitch of the player 
			yaw: yaw of the player 
		"""
		pass

	@overload
	def __init__(self, movementForward: float, movementSideways: float, yaw: float, pitch: float, jumping: bool, sneaking: bool, sprinting: bool) -> None:
		"""Creates a new 'PlayerInput' Object with all double values converted to floats\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			sprinting: sprint input 
			jumping: jump input 
			sneaking: sneak input 
			pitch: pitch of the player 
			yaw: yaw of the player 
			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
		"""
		pass

	@overload
	def __init__(self, movementForward: float, movementSideways: float, yaw: float, pitch: float, jumping: bool, sneaking: bool, sprinting: bool) -> None:
		"""Creates a new 'PlayerInput' Object\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			sprinting: sprint input 
			jumping: jump input 
			sneaking: sneak input 
			pitch: pitch of the player 
			yaw: yaw of the player 
			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
		"""
		pass

	@overload
	def __init__(self, input: "PlayerInput") -> None:
		"""Creates a clone 'PlayerInput' Object\n
		Since: 1.4.0 

		Args:
			input: the 'PlayerInput' object to be cloned 
		"""
		pass

	@overload
	def fromCsv(self, csv: str) -> List["PlayerInput"]:
		"""Parses each row of CSV string into a 'PlayerInput' .
The capitalization of the header matters. About the columns:  
-  'movementForward' and 'movementSideways' as a number  
- 'yaw' and 'pitch' as an absolute number  
- 'jumping' , 'sneaking' and 'sprinting' have to be boolean   
The separation must be a "," it's a csv...(but spaces don't matter) Quoted values don't work\n
		Since: 1.4.0 

		Args:
			csv: CSV string to be parsed 

		Returns:
			'List<PlayerInput>' Each row parsed as a 'PlayerInput' 
		"""
		pass

	@overload
	def fromJson(self, json: str) -> "PlayerInput":
		"""Parses a JSON string into a 'PlayerInput' Object Capitalization of the keys matters.\n
		Since: 1.4.0 

		Args:
			json: JSON string to be parsed 

		Returns:
			The JSON parsed into a 'PlayerInput' 
		"""
		pass

	@overload
	def toString(self, varNames: bool) -> str:
		"""Converts the current object into a string.
This can be used to convert current inputs created using 'Player.getCurrentPlayerInput()' to either JSON or CSV. 
The output can be converted into a PlayerInput object again by using either 'fromCsv(String, String)' or 'fromJson(String)' .\n
		Since: 1.4.0 

		Args:
			varNames: whether to include variable Names(=JSON) or not(=CSV) 

		Returns:
			The 'PlayerInput' object as a string 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def clone(self) -> "PlayerInput":
		pass

	pass





from typing import overload
from typing import List
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder


class ClassBuilder_FieldBuilder_FieldInitializerBuilder:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def setInt(self, value: int) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setLong(self, value: float) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setFloat(self, value: float) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setDouble(self, value: float) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setChar(self, value: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setString(self, value: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setBoolean(self, value: bool) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setByte(self, value: float) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def setShort(self, value: float) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def compile(self, code: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def initClass(self, clazz: Class, code_arg: List[str]) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def callStaticMethod(self, clazz: Class, methodName: str, code_arg: List[str]) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def callStaticMethodInThisClass(self, methodName: str, code_arg: List[str]) -> "ClassBuilder_FieldBuilder":
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_mob_PhantomEntity = TypeVar("net_minecraft_entity_mob_PhantomEntity")
PhantomEntity = net_minecraft_entity_mob_PhantomEntity


class PhantomEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PhantomEntity) -> None:
		pass

	@overload
	def getSize(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the size of this phantom. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping

T = TypeVar("T")
com_google_gson_JsonObject = TypeVar("com_google_gson_JsonObject")
JsonObject = com_google_gson_JsonObject

org_slf4j_Logger = TypeVar("org_slf4j_Logger")
Logger = org_slf4j_Logger

java_io_File = TypeVar("java_io_File")
File = java_io_File


class ConfigManager:
	optionClasses: Mapping[str, Class]
	options: Mapping[Class, object]
	configFolder: File
	macroFolder: File
	configFile: File
	LOGGER: Logger
	rawOptions: JsonObject

	@overload
	def __init__(self, configFolder: File, macroFolder: File, logger: Logger) -> None:
		pass

	@overload
	def reloadRawConfigFromFile(self) -> None:
		pass

	@overload
	def convertConfigFormat(self) -> None:
		pass

	@overload
	def convertConfigFormat(self, clazz: Class) -> None:
		pass

	@overload
	def getOptions(self, optionClass: Class) -> T:
		pass

	@overload
	def addOptions(self, key: str, optionClass: Class) -> None:
		pass

	@overload
	def loadConfig(self) -> None:
		pass

	@overload
	def loadDefaults(self) -> None:
		pass

	@overload
	def saveConfig(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .ProxyBuilder_MethodSigParts import ProxyBuilder_MethodSigParts
from .MethodWrapper import MethodWrapper

T = TypeVar("T")

class ProxyBuilder(Generic[T]):
	"""
	Since: 1.6.0 
	"""
	factory: ProxyFactory
	proxiedMethods: Mapping[ProxyBuilder_MethodSigParts, MethodWrapper]
	proxiedMethodDefaults: Mapping[str, MethodWrapper]

	@overload
	def __init__(self, clazz: Class, interfaces: List[Class]) -> None:
		pass

	@overload
	def addMethod(self, methodNameOrSig: str, proxyMethod: MethodWrapper) -> "ProxyBuilder":
		"""
		Since: 1.6.0 

		Args:
			proxyMethod: 
			methodNameOrSig: name of method or sig (the usual format) 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def buildInstance(self, constructorArgs: List[object]) -> T:
		"""
		Since: 1.6.0 

		Args:
			constructorArgs: args for the super constructor 

		Returns:
			new instance of the constructor 
		"""
		pass

	@overload
	def buildInstance(self, constructorSig: str, constructorArgs: List[object]) -> T:
		"""
		Since: 1.6.0 

		Args:
			constructorArgs: args for the super constructor 
			constructorSig: string signature (you can skip the init part) 

		Returns:
			new instance of the constructor 
		"""
		pass

	@overload
	def buildInstance(self, constructorSig: List[Class], constructorArgs: List[object]) -> T:
		"""
		Since: 1.6.0 

		Args:
			constructorArgs: args for the super constructor 
			constructorSig: string signature (you can skip the init part) 

		Returns:
			new instance of the constructor 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .DisplayEntityHelper import DisplayEntityHelper
from .ItemStackHelper import ItemStackHelper

net_minecraft_entity_decoration_DisplayEntity_ItemDisplayEntity = TypeVar("net_minecraft_entity_decoration_DisplayEntity_ItemDisplayEntity")
DisplayEntity_ItemDisplayEntity = net_minecraft_entity_decoration_DisplayEntity_ItemDisplayEntity


class ItemDisplayEntityHelper(DisplayEntityHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: DisplayEntity_ItemDisplayEntity) -> None:
		pass

	@overload
	def getItem(self) -> ItemStackHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getTransform(self) -> str:
		"""
		Since: 1.9.1 

		Returns:
			"none", "thirdperson_lefthand", "thirdperson_righthand", "firstperson_lefthand",
        "firstperson_righthand", "head", "gui", "ground" or "fixed" 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement import RenderElement
from .Alignable import Alignable
from .IDraw2D import IDraw2D

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class Image(RenderElement, Alignable):
	"""
	Since: 1.2.3 
	"""
	parent: IDraw2D
	rotation: float
	rotateCenter: bool
	x: int
	y: int
	width: int
	height: int
	imageX: int
	imageY: int
	regionWidth: int
	regionHeight: int
	textureWidth: int
	textureHeight: int
	color: int
	zIndex: int

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> None:
		pass

	@overload
	def setImage(self, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> "Image":
		"""
		Since: 1.2.3 

		Args:
			imageY: 
			textureWidth: 
			imageX: 
			regionHeight: 
			id: 
			regionWidth: 
			textureHeight: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getImage(self) -> str:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def setX(self, x: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			x: the new x position of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of this image. 
		"""
		pass

	@overload
	def setY(self, y: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			y: the new y position of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of this image. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			x: the new x position of this image 
			y: the new y position of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> "Image":
		"""
		Since: 1.2.3 

		Args:
			x: 
			width: 
			y: 
			height: 
		"""
		pass

	@overload
	def setWidth(self, width: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			width: the new width of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of this image. 
		"""
		pass

	@overload
	def setHeight(self, height: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			height: the new height of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of this image. 
		"""
		pass

	@overload
	def setSize(self, width: int, height: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			width: the new width of this image 
			height: the new height of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setColor(self, color: int) -> "Image":
		"""
		Since: 1.6.5 

		Args:
			color: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> "Image":
		"""
		Since: 1.6.5 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of this image. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of this image. 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "Image":
		"""
		Since: 1.2.6 

		Args:
			rotation: 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation of this image. 
		"""
		pass

	@overload
	def setRotateCenter(self, rotateCenter: bool) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether the image should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this image should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> "Image":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the new z-index of this image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def setParent(self, parent: IDraw2D) -> "Image":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Image":
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_network_packet_Packet__ = TypeVar("net_minecraft_network_packet_Packet__")
Packet = net_minecraft_network_packet_Packet__


class MixinClientConnection:
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def modifyReceivedPacket(self, packet: Packet) -> Packet:
		pass

	@overload
	def modifySendPacket(self, packet: Packet) -> Packet:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .Mappings_ClassData import Mappings_ClassData
from .Mappings_MappedClass import Mappings_MappedClass

T = TypeVar("T")

class Mappings:
	"""
	Since: 1.3.1 
	"""
	mappingsource: str

	@overload
	def __init__(self, mappingsource: str) -> None:
		pass

	@overload
	def getMappings(self) -> Mapping[str, Mappings_ClassData]:
		"""
		Since: 1.3.1 

		Returns:
			mappings from Intermediary to Named 
		"""
		pass

	@overload
	def getReversedMappings(self) -> Mapping[str, Mappings_ClassData]:
		"""
		Since: 1.3.1 

		Returns:
			mappings from Named to Intermediary 
		"""
		pass

	@overload
	def remapClass(self, instance: T) -> Mappings_MappedClass:
		"""
		Since: 1.6.0 
		"""
		pass

	@overload
	def getClass(self, className: str) -> Mappings_MappedClass:
		"""gets the class without instance, so can only access static methods/fields

		Args:
			className: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_vehicle_TntMinecartEntity = TypeVar("net_minecraft_entity_vehicle_TntMinecartEntity")
TntMinecartEntity = net_minecraft_entity_vehicle_TntMinecartEntity


class TntMinecartEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: TntMinecartEntity) -> None:
		pass

	@overload
	def getRemainingTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining time in ticks before the tnt explodes, or '-1' if the tnt is not
primed. 
		"""
		pass

	@overload
	def isPrimed(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the tnt is primed, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventKey(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	action: int
	key: str
	mods: str

	@overload
	def __init__(self, action: int, key: str, mods: str) -> None:
		pass

	@overload
	def parse(self, key: int, scancode: int, action: int, mods: int) -> bool:
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def getKeyModifiers(self, mods: int) -> str:
		"""turn an Integer for key modifiers into a Translation Key.

		Args:
			mods: 
		"""
		pass

	@overload
	def getModInt(self, mods: str) -> int:
		"""turn a Translation Key for modifiers into an Integer .

		Args:
			mods: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Set
from .BaseLibrary import BaseLibrary

net_minecraft_client_util_InputUtil_Key = TypeVar("net_minecraft_client_util_InputUtil_Key")
InputUtil_Key = net_minecraft_client_util_InputUtil_Key


class FKeyBind(BaseLibrary):
	"""Functions for getting and modifying key pressed states. 
An instance of this class is passed to scripts as the 'KeyBind' variable.
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getKeyCode(self, keyName: str) -> InputUtil_Key:
		"""Dont use this one... get the raw minecraft keycode class.

		Args:
			keyName: 

		Returns:
			the raw minecraft keycode class 
		"""
		pass

	@overload
	def getKeyBindings(self) -> Mapping[str, str]:
		"""
		Since: 1.2.2 

		Returns:
			A Map of all the minecraft keybinds. 
		"""
		pass

	@overload
	def setKeyBind(self, bind: str, key: str) -> None:
		"""Sets a minecraft keybind to the specified key.\n
		Since: 1.2.2 

		Args:
			bind: 
			key: 
		"""
		pass

	@overload
	def key(self, keyName: str, keyState: bool) -> None:
		"""Set a key-state for a key.

		Args:
			keyState: 
			keyName: 
		"""
		pass

	@overload
	def pressKey(self, keyName: str) -> None:
		"""Calls FKeyBind#key(java.lang.String,boolean) with keyState set to true.\n
		Since: 1.8.4 

		Args:
			keyName: the name of the key to press 
		"""
		pass

	@overload
	def releaseKey(self, keyName: str) -> None:
		"""Calls FKeyBind#key(java.lang.String,boolean) with keyState set to false.\n
		Since: 1.8.4 

		Args:
			keyName: the name of the key to release 
		"""
		pass

	@overload
	def keyBind(self, keyBind: str, keyState: bool) -> None:
		"""Set a key-state using the name of the keybind rather than the name of the key. 
This is probably the one you should use.\n
		Since: 1.2.2 

		Args:
			keyBind: 
			keyState: 
		"""
		pass

	@overload
	def pressKeyBind(self, keyBind: str) -> None:
		"""Calls FKeyBind#keyBind(java.lang.String,boolean) with keyState set to true.\n
		Since: 1.8.4 

		Args:
			keyBind: the name of the keybinding to press 
		"""
		pass

	@overload
	def releaseKeyBind(self, keyBind: str) -> None:
		"""Calls FKeyBind#keyBind(java.lang.String,boolean) with keyState set to false.\n
		Since: 1.8.4 

		Args:
			keyBind: the name of the keybinding to release 
		"""
		pass

	@overload
	def getPressedKeys(self) -> Set[str]:
		"""
		Since: 1.2.6 (turned into set instead of list in 1.6.5) 

		Returns:
			a set of currently pressed keys. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__ = TypeVar("net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__")
TrackedData = net_minecraft_entity_data_TrackedData_java_util_Optional_net_minecraft_text_Text__


class MixinEntity2:

	@overload
	def getCustomNameKey(self) -> TrackedData:
		pass

	pass





from typing import overload
from .Alignable import Alignable
from .RenderElementBuilder import RenderElementBuilder
from .IDraw2D import IDraw2D
from .TextHelper import TextHelper
from .TextBuilder import TextBuilder
from .Text import Text


class Text_Builder(Alignable, RenderElementBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, draw2D: IDraw2D) -> None:
		pass

	@overload
	def text(self, text: TextHelper) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			text: the content of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def text(self, text: TextBuilder) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			text: the content of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def text(self, text: str) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			text: the content of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getText(self) -> TextHelper:
		"""
		Since: 1.8.4 

		Returns:
			the content of the text element. 
		"""
		pass

	@overload
	def x(self, x: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the text element. 
		"""
		pass

	@overload
	def y(self, y: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			y: the y position of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the text element. 
		"""
		pass

	@overload
	def pos(self, x: int, y: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the text element 
			y: the y position of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the string. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the string. 
		"""
		pass

	@overload
	def color(self, color: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha component of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the text element. 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			scale: the scale of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getScale(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the scale of the text element. 
		"""
		pass

	@overload
	def rotation(self, rotation: float) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the text element in degrees 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the text element in degrees. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this text should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this text should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def shadow(self, shadow: bool) -> "Text_Builder":
		"""
		Since: 1.8.4 

		Args:
			shadow: whether the text should have a shadow or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def hasShadow(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the text element has a shadow, 'false' otherwise. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> "Text_Builder":
		"""

		Args:
			zIndex: the z-index of the text element 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the text element. 
		"""
		pass

	@overload
	def createElement(self) -> Text:
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Text_Builder":
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_vehicle_BoatEntity_Location = TypeVar("net_minecraft_entity_vehicle_BoatEntity_Location")
BoatEntity_Location = net_minecraft_entity_vehicle_BoatEntity_Location


class MixinBoatEntity:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getLocation(self) -> BoatEntity_Location:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper
from .TextHelper import TextHelper

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class EventNameChange(BaseEvent):
	"""
	Since: 1.9.1 
	"""
	entity: EntityHelper
	oldName: TextHelper
	newName: TextHelper

	@overload
	def __init__(self, entity: Entity, oldName: Text, newName: Text) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .Inventory import Inventory

net_minecraft_client_gui_screen_ingame_HandledScreen__ = TypeVar("net_minecraft_client_gui_screen_ingame_HandledScreen__")
HandledScreen = net_minecraft_client_gui_screen_ingame_HandledScreen__


class EventDropSlot(BaseEvent):
	"""event triggered when an item is dropped\n
	Since: 1.6.4 
	"""
	slot: int
	all: bool

	@overload
	def __init__(self, screen: HandledScreen, slot: int, all: bool) -> None:
		pass

	@overload
	def getInventory(self) -> Inventory:
		"""

		Returns:
			inventory associated with the event 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_gui_editor_SelectCursor_ = TypeVar("java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_gui_editor_SelectCursor_")
Consumer = java_util_function_Consumer_xyz_wagyourtail_jsmacros_client_gui_editor_SelectCursor_

net_minecraft_text_Style = TypeVar("net_minecraft_text_Style")
Style = net_minecraft_text_Style


class SelectCursor:
	onChange: Consumer
	defaultStyle: Style
	startLine: int
	endLine: int
	startIndex: int
	endIndex: int
	startLineIndex: int
	endLineIndex: int
	dragStartIndex: int
	arrowLineIndex: int
	arrowEnd: bool
	startCol: int
	endCol: int

	@overload
	def __init__(self, defaultStyle: Style) -> None:
		pass

	@overload
	def updateStartIndex(self, startIndex: int, current: str) -> None:
		pass

	@overload
	def updateEndIndex(self, endIndex: int, current: str) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .BlockStateHelper import BlockStateHelper
from .ItemStackHelper import ItemStackHelper
from .TextHelper import TextHelper

net_minecraft_block_Block = TypeVar("net_minecraft_block_Block")
Block = net_minecraft_block_Block


class BlockHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: Block) -> None:
		pass

	@overload
	def getDefaultState(self) -> BlockStateHelper:
		"""
		Since: 1.6.5 

		Returns:
			the default state of the block. 
		"""
		pass

	@overload
	def getDefaultItemStack(self) -> ItemStackHelper:
		"""
		Since: 1.6.5 

		Returns:
			the default item stack of the block. 
		"""
		pass

	@overload
	def canMobSpawnInside(self) -> bool:
		pass

	@overload
	def hasDynamicBounds(self) -> bool:
		"""
		Since: 1.6.5 

		Returns:
			'true' if the block has dynamic bounds. 
		"""
		pass

	@overload
	def getBlastResistance(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the blast resistance. 
		"""
		pass

	@overload
	def getJumpVelocityMultiplier(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the jump velocity multiplier. 
		"""
		pass

	@overload
	def getSlipperiness(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the slipperiness. 
		"""
		pass

	@overload
	def getHardness(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the hardness. 
		"""
		pass

	@overload
	def getVelocityMultiplier(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			the velocity multiplier. 
		"""
		pass

	@overload
	def getTags(self) -> List[str]:
		"""
		Since: 1.6.5 

		Returns:
			all tags of the block as an ArrayList . 
		"""
		pass

	@overload
	def getStates(self) -> List[BlockStateHelper]:
		"""
		Since: 1.6.5 

		Returns:
			all possible block states of the block. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			the identifier of the block. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""
		Since: 1.8.4 

		Returns:
			the name of the block. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping

net_minecraft_advancement_AdvancementRequirements = TypeVar("net_minecraft_advancement_AdvancementRequirements")
AdvancementRequirements = net_minecraft_advancement_AdvancementRequirements

net_minecraft_advancement_criterion_CriterionProgress = TypeVar("net_minecraft_advancement_criterion_CriterionProgress")
CriterionProgress = net_minecraft_advancement_criterion_CriterionProgress


class MixinAdvancementProgress:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getRequirements(self) -> AdvancementRequirements:
		pass

	@overload
	def invokeCountObtainedRequirements(self) -> int:
		pass

	@overload
	def getCriteriaProgresses(self) -> Mapping[str, CriterionProgress]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Button import Button

java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Button_ = TypeVar("java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Button_")
Consumer = java_util_function_Consumer_xyz_wagyourtail_wagyourgui_elements_Button_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class AnnotatedCheckBox(Button):
	value: bool

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, color: int, borderColor: int, highlightColor: int, textColor: int, message: Text, initialValue: bool, onPress: Consumer) -> None:
		pass

	@overload
	def onPress(self) -> None:
		pass

	@overload
	def setMessage(self, message: Text) -> None:
		pass

	@overload
	def renderWidget(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventLaunchGame(BaseEvent):
	"""
	Since: 1.8.4 
	"""
	playerName: str

	@overload
	def __init__(self, playerName: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .ClickableWidgetHelper import ClickableWidgetHelper

T = TypeVar("T")

class ButtonWidgetHelper(Generic[T], ClickableWidgetHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, btn: T) -> None:
		pass

	@overload
	def __init__(self, btn: T, zIndex: int) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .ScoreboardObjectiveHelper import ScoreboardObjectiveHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .FormattingHelper import FormattingHelper
from .TeamHelper import TeamHelper

net_minecraft_scoreboard_Scoreboard = TypeVar("net_minecraft_scoreboard_Scoreboard")
Scoreboard = net_minecraft_scoreboard_Scoreboard


class ScoreboardsHelper(BaseHelper):
	"""
	Since: 1.2.9 
	"""

	@overload
	def __init__(self, board: Scoreboard) -> None:
		pass

	@overload
	def getObjectiveForTeamColorIndex(self, index: int) -> ScoreboardObjectiveHelper:
		"""
		Since: 1.2.9 

		Args:
			index: 
		"""
		pass

	@overload
	def getObjectiveSlot(self, slot: int) -> ScoreboardObjectiveHelper:
		"""'0' is tab list, '1' or '3 + getPlayerTeamColorIndex()' is sidebar, '2' should be below name.
therefore max slot number is 18.\n
		Since: 1.2.9 

		Args:
			slot: 
		"""
		pass

	@overload
	def getPlayerTeamColorIndex(self, entity: PlayerEntityHelper) -> int:
		"""
		Since: 1.2.9 

		Args:
			entity: 
		"""
		pass

	@overload
	def getPlayerTeamColorIndex(self) -> int:
		"""
		Since: 1.6.5 

		Returns:
			team index for client player 
		"""
		pass

	@overload
	def getTeamColorFormatting(self) -> FormattingHelper:
		"""
		Since: 1.8.4 

		Returns:
			the formatting for the client player's team, 'null' if the player is not in a
team. 
		"""
		pass

	@overload
	def getTeamColorFormatting(self, player: PlayerEntityHelper) -> FormattingHelper:
		"""
		Since: 1.8.4 

		Args:
			player: the player to get the team color's formatting for. 

		Returns:
			the formatting for the client player's team, 'null' if the player is not in a
team. 
		"""
		pass

	@overload
	def getTeamColor(self, player: PlayerEntityHelper) -> int:
		"""
		Since: 1.8.4 

		Args:
			player: the player to get the team color for 

		Returns:
			the color of the specified player's team or '-1' if the player is not in a team. 
		"""
		pass

	@overload
	def getTeamColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of this player's team or '-1' if this player is not in a team. 
		"""
		pass

	@overload
	def getTeamColorName(self, player: PlayerEntityHelper) -> str:
		"""
		Since: 1.8.4 

		Args:
			player: the player to get the team color's name for 

		Returns:
			the name of the specified player's team color or 'null' if the player is not in
a team. 
		"""
		pass

	@overload
	def getTeamColorName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the color of this player's team or 'null' if this player is not in a team. 
		"""
		pass

	@overload
	def getTeams(self) -> List[TeamHelper]:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getPlayerTeam(self, p: PlayerEntityHelper) -> TeamHelper:
		"""
		Since: 1.3.0 

		Args:
			p: 
		"""
		pass

	@overload
	def getPlayerTeam(self) -> TeamHelper:
		"""
		Since: 1.6.5 

		Returns:
			team for client player 
		"""
		pass

	@overload
	def getCurrentScoreboard(self) -> ScoreboardObjectiveHelper:
		"""
		Since: 1.2.9 

		Returns:
			the ScoreboardObjectiveHelper for the currently displayed sidebar scoreboard. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping
from .BaseEvent import BaseEvent
from .MethodWrapper import MethodWrapper
from .Registrable import Registrable


class EventService(BaseEvent):
	"""
	Since: 1.6.4 
	"""
	serviceName: str
	stopListener: MethodWrapper
	postStopListener: MethodWrapper

	@overload
	def __init__(self, name: str) -> None:
		pass

	@overload
	def unregisterOnStop(self, offEvents: bool, list: List[Registrable]) -> None:
		"""Setup unregister on stop. For example, 'event.unregisterOnStop(false, d2d);' is
the equivalent of 'event.stopListener = JavaWrapper.methodToJava(() => d2d.unregister());' .  If this is called multiple times, the previous ones would be discarded.  The order of execution is run stopListener -> off events -> unregister stuff -> run postStopListener.  If anything was set to unregister, the service won't stop by itself even if it reaches the end.\n
		Since: 1.9.1 

		Args:
			offEvents: whether the service manager should clear event listeners that the callback doesn't belong to this context. 
			list: the list of registrable, such as Draw2D, Draw3D and CommandBuilder. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def putInt(self, name: str, i: int) -> int:
		"""Put an Integer into the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
			i: 
		"""
		pass

	@overload
	def putString(self, name: str, str: str) -> str:
		"""put a String into the global variable space.\n
		Since: 1.6.5 

		Args:
			str: 
			name: 
		"""
		pass

	@overload
	def putDouble(self, name: str, d: float) -> float:
		"""put a Double into the global variable space.\n
		Since: 1.6.5 

		Args:
			d: 
			name: 
		"""
		pass

	@overload
	def putBoolean(self, name: str, b: bool) -> bool:
		"""put a Boolean into the global variable space.\n
		Since: 1.6.5 

		Args:
			b: 
			name: 
		"""
		pass

	@overload
	def putObject(self, name: str, o: object) -> object:
		"""put anything else into the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
			o: 
		"""
		pass

	@overload
	def getType(self, name: str) -> str:
		"""Returns the type of the defined item in the global variable space as a string.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getInt(self, name: str) -> int:
		"""Gets an Integer from the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getAndIncrementInt(self, name: str) -> int:
		"""Gets an Integer from the global variable space. and then increment it there.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getAndDecrementInt(self, name: str) -> int:
		"""Gets an integer from the global variable pace. and then decrement it there.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def incrementAndGetInt(self, name: str) -> int:
		"""increment an Integer in the global variable space. then return it.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def decrementAndGetInt(self, name: str) -> int:
		"""decrement an Integer in the global variable space. then return it.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getString(self, name: str) -> str:
		"""Gets a String from the global variable space\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getDouble(self, name: str) -> float:
		"""Gets a Double from the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getBoolean(self, name: str) -> bool:
		"""Gets a Boolean from the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def toggleBoolean(self, name: str) -> bool:
		"""toggles a global boolean and returns its new value\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getObject(self, name: str) -> object:
		"""Gets an Object from the global variable space.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def remove(self, key: str) -> None:
		"""removes a key from the global variable space.\n
		Since: 1.6.5 

		Args:
			key: 
		"""
		pass

	@overload
	def getRaw(self) -> Mapping[str, object]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .NBTElementHelper import NBTElementHelper

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID


class NBTElementHelper_NBTListHelper(NBTElementHelper):
	"""
	Since: 1.5.1 
	"""

	@overload
	def isPossiblyUUID(self) -> bool:
		"""
		Since: 1.8.3 
		"""
		pass

	@overload
	def asUUID(self) -> UUID:
		"""
		Since: 1.8.3 
		"""
		pass

	@overload
	def length(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def get(self, index: int) -> NBTElementHelper:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def getHeldType(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventFilterer:
	"""
	Since: 1.9.1 
	"""

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, event: BaseEvent) -> bool:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventMouseScroll(BaseEvent):
	"""
	Since: 1.9.0 
	"""
	deltaX: float
	deltaY: float

	@overload
	def __init__(self, deltaX: float, deltaY: float) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .IEventListener import IEventListener
from .MethodWrapper import MethodWrapper


class FJsMacros_ScriptEventListener(IEventListener):

	@overload
	def getCreatorName(self) -> str:
		pass

	@overload
	def getWrapper(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Set

java_util_concurrent_CompletableFuture_com_mojang_brigadier_suggestion_Suggestions_ = TypeVar("java_util_concurrent_CompletableFuture_com_mojang_brigadier_suggestion_Suggestions_")
CompletableFuture = java_util_concurrent_CompletableFuture_com_mojang_brigadier_suggestion_Suggestions_

com_mojang_brigadier_context_CommandContext__ = TypeVar("com_mojang_brigadier_context_CommandContext__")
CommandContext = com_mojang_brigadier_context_CommandContext__

net_minecraft_client_network_ClientCommandSource = TypeVar("net_minecraft_client_network_ClientCommandSource")
ClientCommandSource = net_minecraft_client_network_ClientCommandSource

net_minecraft_command_CommandSource_RelativePosition = TypeVar("net_minecraft_command_CommandSource_RelativePosition")
CommandSource_RelativePosition = net_minecraft_command_CommandSource_RelativePosition

net_minecraft_registry_DynamicRegistryManager = TypeVar("net_minecraft_registry_DynamicRegistryManager")
DynamicRegistryManager = net_minecraft_registry_DynamicRegistryManager

java_util_stream_Stream_net_minecraft_util_Identifier_ = TypeVar("java_util_stream_Stream_net_minecraft_util_Identifier_")
Stream = java_util_stream_Stream_net_minecraft_util_Identifier_

java_util_function_Supplier_net_minecraft_text_Text_ = TypeVar("java_util_function_Supplier_net_minecraft_text_Text_")
Supplier = java_util_function_Supplier_net_minecraft_text_Text_

net_minecraft_client_network_ClientPlayerEntity = TypeVar("net_minecraft_client_network_ClientPlayerEntity")
ClientPlayerEntity = net_minecraft_client_network_ClientPlayerEntity

net_minecraft_registry_RegistryKey_net_minecraft_world_World_ = TypeVar("net_minecraft_registry_RegistryKey_net_minecraft_world_World_")
RegistryKey = net_minecraft_registry_RegistryKey_net_minecraft_world_World_

net_minecraft_server_command_ServerCommandSource = TypeVar("net_minecraft_server_command_ServerCommandSource")
ServerCommandSource = net_minecraft_server_command_ServerCommandSource


class FakeServerCommandSource(ServerCommandSource):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, source: ClientCommandSource, player: ClientPlayerEntity) -> None:
		pass

	@overload
	def getEntitySuggestions(self) -> List[str]:
		pass

	@overload
	def getChatSuggestions(self) -> List[str]:
		pass

	@overload
	def getPlayerNames(self) -> List[str]:
		pass

	@overload
	def getTeamNames(self) -> List[str]:
		pass

	@overload
	def getSoundIds(self) -> Stream:
		pass

	@overload
	def getRecipeIds(self) -> Stream:
		pass

	@overload
	def getCompletions(self, context: CommandContext) -> CompletableFuture:
		pass

	@overload
	def getBlockPositionSuggestions(self) -> List[CommandSource_RelativePosition]:
		pass

	@overload
	def getPositionSuggestions(self) -> List[CommandSource_RelativePosition]:
		pass

	@overload
	def getWorldKeys(self) -> Set[RegistryKey]:
		pass

	@overload
	def getRegistryManager(self) -> DynamicRegistryManager:
		pass

	@overload
	def sendFeedback(self, feedbackSupplier: Supplier, broadcastToOps: bool) -> None:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .BaseProfile import BaseProfile


class EventProfileLoad(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	profileName: str

	@overload
	def __init__(self, profile: BaseProfile, profileName: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload


class IMixinEntity:

	@overload
	def jsmacros_setGlowingColor(self, glowingColor: int) -> None:
		pass

	@overload
	def jsmacros_resetColor(self) -> None:
		pass

	@overload
	def jsmacros_setForceGlowing(self, glowing: int) -> None:
		"""

		Args:
			glowing: 1 for enabled, 2 for forced 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IOverlayParent import IOverlayParent
from .OverlayContainer import OverlayContainer

T = TypeVar("T")
net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_gui_Element = TypeVar("net_minecraft_client_gui_Element")
Element = net_minecraft_client_gui_Element

net_minecraft_text_StringVisitable = TypeVar("net_minecraft_text_StringVisitable")
StringVisitable = net_minecraft_text_StringVisitable

net_minecraft_text_OrderedText = TypeVar("net_minecraft_text_OrderedText")
OrderedText = net_minecraft_text_OrderedText

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class BaseScreen(IOverlayParent, Screen):

	@overload
	def trimmed(self, textRenderer: TextRenderer, str: StringVisitable, width: int) -> OrderedText:
		pass

	@overload
	def setParent(self, parent: Screen) -> None:
		pass

	@overload
	def reload(self) -> None:
		pass

	@overload
	def removed(self) -> None:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer) -> None:
		pass

	@overload
	def getFirstOverlayParent(self) -> IOverlayParent:
		pass

	@overload
	def getChildOverlay(self) -> OverlayContainer:
		pass

	@overload
	def openOverlay(self, overlay: OverlayContainer, disableButtons: bool) -> None:
		pass

	@overload
	def closeOverlay(self, overlay: OverlayContainer) -> None:
		pass

	@overload
	def remove(self, btn: Element) -> None:
		pass

	@overload
	def addDrawableChild(self, drawableElement: T) -> T:
		pass

	@overload
	def setFocused(self, focused: Element) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, horiz: float, vert: float) -> bool:
		pass

	@overload
	def mouseClicked(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def shouldCloseOnEsc(self) -> bool:
		pass

	@overload
	def updateSettings(self) -> None:
		pass

	@overload
	def close(self) -> None:
		pass

	@overload
	def openParent(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseEvent import BaseEvent
from .PacketByteBufferHelper import PacketByteBufferHelper

net_minecraft_network_packet_Packet__ = TypeVar("net_minecraft_network_packet_Packet__")
Packet = net_minecraft_network_packet_Packet__


class EventSendPacket(BaseEvent):
	"""
	Since: 1.8.4 
	"""
	packet: Packet
	type: str

	@overload
	def __init__(self, packet: Packet) -> None:
		pass

	@overload
	def replacePacket(self, args: List[object]) -> None:
		"""Replaces the packet of this event with a new one of the same type, created from the given
arguments. It's recommended to use EventSendPacket#getPacketBuffer() to modify the packet instead.\n
		Since: 1.8.4 

		Args:
			args: the arguments to pass to the packet's constructor 
		"""
		pass

	@overload
	def getPacketBuffer(self) -> PacketByteBufferHelper:
		"""After modifying the buffer, use PacketByteBufferHelper#toPacket() to get the modified
packet and replace this packet with the modified one.\n
		Since: 1.8.4 

		Returns:
			a helper for accessing and modifying the packet's data. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .Vec3D import Vec3D


class Plane3D:
	"""
	Since: 1.6.5 
	"""
	x1: float
	y1: float
	z1: float
	x2: float
	y2: float
	z2: float
	x3: float
	y3: float
	z3: float

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, x3: float, y3: float, z3: float) -> None:
		pass

	@overload
	def getNormalVector(self) -> Vec3D:
		pass

	@overload
	def getVec12(self) -> Vec3D:
		pass

	@overload
	def getVec13(self) -> Vec3D:
		pass

	@overload
	def getVec23(self) -> Vec3D:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IRecipeBookResults import IRecipeBookResults

net_minecraft_client_gui_screen_recipebook_RecipeResultCollection = TypeVar("net_minecraft_client_gui_screen_recipebook_RecipeResultCollection")
RecipeResultCollection = net_minecraft_client_gui_screen_recipebook_RecipeResultCollection


class MixinRecipeBookResults(IRecipeBookResults):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getResultCollections(self) -> List[RecipeResultCollection]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper
from .EntityHelper import EntityHelper

net_minecraft_entity_mob_GuardianEntity = TypeVar("net_minecraft_entity_mob_GuardianEntity")
GuardianEntity = net_minecraft_entity_mob_GuardianEntity


class GuardianEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: GuardianEntity) -> None:
		pass

	@overload
	def isElder(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this guardian is an elder guardian, 'false' otherwise. 
		"""
		pass

	@overload
	def hasTarget(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this guardian is targeting a mob, 'false' otherwise. 
		"""
		pass

	@overload
	def getTarget(self) -> EntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the target of this guardian's beam, or 'null' if it has no target. 
		"""
		pass

	@overload
	def hasSpikesRetracted(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this guardian has its spikes extended, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from typing import Generic

java_util_function_Function_E,java_lang_Integer_ = TypeVar("java_util_function_Function_E,java_lang_Integer_")
Function = java_util_function_Function_E,java_lang_Integer_

T = TypeVar("T")
E = TypeVar("E")
E = E

java_util_Queue_E_ = TypeVar("java_util_Queue_E_")
Queue = java_util_Queue_E_


class PrioryFiFoTaskQueue(Queue, Generic[E]):

	@overload
	def __init__(self, priorityFunction: Function) -> None:
		pass

	@overload
	def size(self) -> int:
		pass

	@overload
	def isEmpty(self) -> bool:
		pass

	@overload
	def contains(self, o: object) -> bool:
		pass

	@overload
	def iterator(self) -> iter:
		pass

	@overload
	def toArray(self) -> List[object]:
		pass

	@overload
	def toArray(self, ts: List[T]) -> List[T]:
		pass

	@overload
	def add(self, e: E) -> bool:
		pass

	@overload
	def remove(self, o: object) -> bool:
		pass

	@overload
	def containsAll(self, collection: List[Any]) -> bool:
		pass

	@overload
	def addAll(self, collection: List[Any]) -> bool:
		pass

	@overload
	def removeAll(self, collection: List[Any]) -> bool:
		pass

	@overload
	def retainAll(self, collection: List[Any]) -> bool:
		pass

	@overload
	def clear(self) -> None:
		pass

	@overload
	def offer(self, e: E) -> bool:
		pass

	@overload
	def remove(self) -> E:
		pass

	@overload
	def poll(self) -> E:
		pass

	@overload
	def pollWaiting(self) -> E:
		pass

	@overload
	def pollWaiting(self, timeout: float) -> E:
		pass

	@overload
	def peekWaiting(self) -> E:
		pass

	@overload
	def peekWaiting(self, timeout: float) -> E:
		pass

	@overload
	def element(self) -> E:
		pass

	@overload
	def peek(self) -> E:
		pass

	pass





from typing import overload
from .IFilter import IFilter


class CharCompareFilter(IFilter):

	@overload
	def __init__(self, compareTo: str) -> None:
		pass

	@overload
	def apply(self, character: Character) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Button import Button

java_io_File = TypeVar("java_io_File")
File = java_io_File


class FileChooser_fileObj:
	file: File
	btn: Button

	@overload
	def __init__(self, file: File, btn: Button) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper

java_util_function_Function_xyz_wagyourtail_jsmacros_client_api_helpers_world_BlockStateHelper,java_lang_Boolean_ = TypeVar("java_util_function_Function_xyz_wagyourtail_jsmacros_client_api_helpers_world_BlockStateHelper,java_lang_Boolean_")
Function = java_util_function_Function_xyz_wagyourtail_jsmacros_client_api_helpers_world_BlockStateHelper,java_lang_Boolean_

net_minecraft_util_math_ChunkPos = TypeVar("net_minecraft_util_math_ChunkPos")
ChunkPos = net_minecraft_util_math_ChunkPos

net_minecraft_world_World = TypeVar("net_minecraft_world_World")
World = net_minecraft_world_World


class WorldScanner:
	"""A class to scan the world for certain blocks. The results of the filters are cached,
so it's a good idea to reuse an instance of this if possible.
The scanner can either return a list of all block positions or
a list of blocks and their respective count for every block / state matching the filters criteria.\n
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, world: World, blockFilter: Function, stateFilter: Function) -> None:
		"""Creates a new World scanner with for the given world. It accepts two boolean functions,
one for BlockHelper and the other for BlockStateHelper .

		Args:
			world: the world to scan 
			blockFilter: a filter method for the blocks 
			stateFilter: a filter method for the block states 
		"""
		pass

	@overload
	def getChunkRange(self, centerX: int, centerZ: int, chunkrange: int) -> List[ChunkPos]:
		"""Gets a list of all chunks in the given range around the center chunk.

		Args:
			centerZ: the z coordinate of the center chunk to scan around 
			centerX: the x coordinate of the center chunk to scan around 
			chunkrange: the range to scan around the center chunk 

		Returns:
			a list of all matching block positions. 
		"""
		pass

	@overload
	def scanAroundPlayer(self, chunkRange: int) -> List[Pos3D]:
		"""Scans all chunks in the given range around the player and returns a list of all block positions, for blocks matching the filter.
This will scan in a square with length 2*range + 1. So range = 0 for example will only scan the chunk the player
is standing in, while range = 1 will scan in a 3x3 area.

		Args:
			chunkRange: the range to scan around the center chunk 

		Returns:
			a list of all matching block positions. 
		"""
		pass

	@overload
	def scanChunkRange(self, centerX: int, centerZ: int, chunkrange: int) -> List[Pos3D]:
		"""Scans all chunks in the given range around the center chunk and returns a list of all block positions, for blocks matching the filter.
This will scan in a square with length 2*range + 1. So range = 0 for example will only scan the specified chunk,
while range = 1 will scan in a 3x3 area.

		Args:
			centerZ: the z coordinate of the center chunk to scan around 
			centerX: the x coordinate of the center chunk to scan around 
			chunkrange: the range to scan around the center chunk 

		Returns:
			a list of all matching block positions. 
		"""
		pass

	@overload
	def scanCubeArea(self, pos: BlockPosHelper, range: int) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanCubeArea(self, x: int, y: int, z: int, range: int) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanCubeArea(self, pos1: BlockPosHelper, pos2: BlockPosHelper) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 

		Args:
			pos1: first pos, inclusive 
			pos2: second pos, exclusive 
		"""
		pass

	@overload
	def scanCubeArea(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 

		Args:
			z1: first z coordinate, inclusive 
			y1: first y coordinate, inclusive 
			z2: second z coordinate, exclusive 
			x1: first x coordinate, inclusive 
			y2: second y coordinate, exclusive 
			x2: second x coordinate, exclusive 
		"""
		pass

	@overload
	def scanCubeAreaInclusive(self, pos1: BlockPosHelper, pos2: BlockPosHelper) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 

		Args:
			pos1: first pos, inclusive 
			pos2: second pos, inclusive 
		"""
		pass

	@overload
	def scanCubeAreaInclusive(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 

		Args:
			z1: first z coordinate, inclusive 
			y1: first y coordinate, inclusive 
			z2: second z coordinate, inclusive 
			x1: first x coordinate, inclusive 
			y2: second y coordinate, inclusive 
			x2: second x coordinate, inclusive 
		"""
		pass

	@overload
	def scanSphereArea(self, pos: Pos3D, radius: float) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanSphereArea(self, x: float, y: float, z: float, radius: float) -> List[Pos3D]:
		"""scan area in blocks\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanReachable(self) -> List[Pos3D]:
		"""scan around with player pos and player reach. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanReachable(self, strict: bool) -> List[Pos3D]:
		"""scan around with player pos and player reach. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 

		Args:
			strict: if it should check for block outline instead of full cube, default is true 
		"""
		pass

	@overload
	def scanReachable(self, pos: Pos3D) -> List[Pos3D]:
		"""scan around with the given pos and player reach. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanReachable(self, pos: Pos3D, reach: float) -> List[Pos3D]:
		"""scan around with the given pos and the given reach. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanReachable(self, pos: Pos3D, reach: float, strict: bool) -> List[Pos3D]:
		"""scan around with the given pos and the given reach. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 

		Args:
			pos: 'Player.getPlayer().getEyePos()' 
			reach: 'Player.getInteractionManager().getReach()' 
			strict: if it should check for block outline instead of full cube, default is true 
		"""
		pass

	@overload
	def scanClosestReachable(self) -> Pos3D:
		"""scan around with player pos and player reach, and return the closest one. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanClosestReachable(self, strict: bool) -> Pos3D:
		"""scan around with player pos and player reach, and return the closest one. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def scanClosestReachable(self, pos: Pos3D, reach: float, strict: bool) -> Pos3D:
		"""scan around with player pos and player reach, and return the closest one. this doesn't filter out positions that has obstacle.\n
		Since: 1.9.1 
		"""
		pass

	@overload
	def getBlocksInChunk(self, chunkX: int, chunkZ: int, ignoreState: bool) -> Mapping[str, int]:
		"""Gets the amount of all blocks matching the criteria inside the chunk.

		Args:
			ignoreState: whether multiple states should be combined to a single block 
			chunkX: the x coordinate of the chunk to scan 
			chunkZ: the z coordinate of the chunk to scan 

		Returns:
			a map of all blocks inside the specified chunk and their respective count. 
		"""
		pass

	@overload
	def getBlocksInChunks(self, centerX: int, centerZ: int, chunkRange: int, ignoreState: bool) -> Mapping[str, int]:
		"""Gets the amount of all blocks matching the criteria inside a square around the player.

		Args:
			chunkRange: the range to scan around the center chunk 
			centerZ: the z coordinate of the center chunk to scan around 
			ignoreState: whether multiple states should be combined to a single block 
			centerX: the x coordinate of the center chunk to scan around 

		Returns:
			a map of all blocks inside the specified chunks and their respective count. 
		"""
		pass

	@overload
	def getCachedAmount(self) -> int:
		"""Get the amount of cached block states. This will normally be around 200 - 400.

		Returns:
			the amount of cached block states. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

net_minecraft_scoreboard_ScoreboardObjective = TypeVar("net_minecraft_scoreboard_ScoreboardObjective")
ScoreboardObjective = net_minecraft_scoreboard_ScoreboardObjective


class ScoreboardObjectiveHelper(BaseHelper):
	"""
	Since: 1.2.9 
	"""

	@overload
	def __init__(self, o: ScoreboardObjective) -> None:
		pass

	@overload
	def getPlayerScores(self) -> Mapping[str, int]:
		"""

		Returns:
			player name to score map 
		"""
		pass

	@overload
	def scoreToDisplayName(self) -> Mapping[int, TextHelper]:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def getKnownPlayers(self) -> List[str]:
		"""
		Since: 1.7.0 
		"""
		pass

	@overload
	def getKnownPlayersDisplayNames(self) -> List[TextHelper]:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.2.9 

		Returns:
			name of scoreboard 
		"""
		pass

	@overload
	def getDisplayName(self) -> TextHelper:
		"""
		Since: 1.2.9 

		Returns:
			name of scoreboard 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseScreen import BaseScreen
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class ScriptScreen(BaseScreen):
	"""just go look at IScreen since all the methods are done through a mixin...\n
	Since: 1.0.5 
	"""
	drawTitle: bool
	shouldCloseOnEsc: bool
	shouldPause: bool

	@overload
	def __init__(self, title: str, dirt: bool) -> None:
		pass

	@overload
	def setParent(self, parent: IScreen) -> None:
		"""
		Since: 1.4.0 

		Args:
			parent: parent screen to go to when this one exits. 
		"""
		pass

	@overload
	def setOnRender(self, onRender: MethodWrapper) -> None:
		"""add custom stuff to the render function on the main thread.\n
		Since: 1.4.0 

		Args:
			onRender: pos3d elements are mousex, mousey, tickDelta 
		"""
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def close(self) -> None:
		pass

	@overload
	def shouldPause(self) -> bool:
		pass

	@overload
	def shouldCloseOnEsc(self) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MethodWrapper import MethodWrapper

T = TypeVar("T")

class IFWrapper:
	"""FunctionalInterface implementation for wrapping methods to match the language spec. An instance of this class is passed to scripts as the 'consumer' variable. Javascript:
language spec requires that only one thread can hold an instance of the language at a time,
so this implementation uses a non-preemptive priority queue for the threads that call the resulting MethodWrapper . JEP:
language spec requires everything to be on the same thread, on the java end, so all calls to MethodWrapper call back to JEP's starting thread and wait for the call to complete. Jython:
no limitations LUA:
no limitations\n
	Since: 1.2.5, re-named from 'consumer' in 1.3.2 
	"""

	@overload
	def methodToJava(self, c: T) -> MethodWrapper:
		"""
		Since: 1.4.0 

		Args:
			c: 

		Returns:
			a new MethodWrapper 
		"""
		pass

	@overload
	def methodToJavaAsync(self, c: T) -> MethodWrapper:
		"""
		Since: 1.4.0 

		Args:
			c: 

		Returns:
			a new MethodWrapper 
		"""
		pass

	@overload
	def methodToJavaAsync(self, priority: int, c: T) -> MethodWrapper:
		"""JS/JEP ONLY
allows you to set the position of the thread in the queue. you can use this for return value one's too...\n
		Since: 1.8.0 

		Args:
			A: 
			B: 
			R: 
			c: 
			priority: 
		"""
		pass

	@overload
	def deferCurrentTask(self) -> None:
		"""JS/JEP only, puts current task at end of queue.
use with caution, don't accidentally cause circular waiting.\n
		Since: 1.4.0 [citation needed] 
		"""
		pass

	@overload
	def deferCurrentTask(self, priorityAdjust: int) -> None:
		"""JS/JEP only, puts current task at end of queue.
use with caution, don't accidentally cause circular waiting.\n
		Since: 1.8.0 

		Args:
			priorityAdjust: the amount to adjust the priority by 
		"""
		pass

	@overload
	def getCurrentPriority(self) -> int:
		"""JS/JEP only, get priority of current task.\n
		Since: 1.8.0 
		"""
		pass

	@overload
	def stop(self) -> None:
		"""Close the current context\n
		Since: 1.2.2 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

net_minecraft_entity_Entity_RemovalReason = TypeVar("net_minecraft_entity_Entity_RemovalReason")
Entity_RemovalReason = net_minecraft_entity_Entity_RemovalReason

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo


class MixinClientWorld:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onAddEntity(self, entity: Entity, ci: CallbackInfo) -> None:
		pass

	@overload
	def onRemoveEntity(self, entityId: int, removalReason: Entity_RemovalReason, ci: CallbackInfo, entity: Entity) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_CartographyTableScreen = TypeVar("net_minecraft_client_gui_screen_ingame_CartographyTableScreen")
CartographyTableScreen = net_minecraft_client_gui_screen_ingame_CartographyTableScreen


class CartographyInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: CartographyTableScreen) -> None:
		pass

	@overload
	def getMapItem(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the map item. 
		"""
		pass

	@overload
	def getMaterial(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the paper item. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the output item. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .EventEXPChange import EventEXPChange
from .EventCustom import EventCustom
from .EventRecvMessage import EventRecvMessage
from .EventWrappedScript import EventWrappedScript
from .EventAirChange import EventAirChange
from .EventSlotUpdate import EventSlotUpdate
from .CodeCompileEvent import CodeCompileEvent
from .EventResourcePackLoaded import EventResourcePackLoaded
from .EventMouseScroll import EventMouseScroll
from .EventItemDamage import EventItemDamage
from .EventTitle import EventTitle
from .EventOpenContainer import EventOpenContainer
from .EventBossbar import EventBossbar
from .EventAttackBlock import EventAttackBlock
from .EventDamage import EventDamage
from .EventPlayerLeave import EventPlayerLeave
from .EventChunkLoad import EventChunkLoad
from .EventHungerChange import EventHungerChange
from .EventHealthChange import EventHealthChange
from .EventDropSlot import EventDropSlot
from .EventRiding import EventRiding
from .EventEntityUnload import EventEntityUnload
from .EventJoinServer import EventJoinServer
from .EventLaunchGame import EventLaunchGame
from .EventEntityDamaged import EventEntityDamaged
from .EventStatusEffectUpdate import EventStatusEffectUpdate
from .EventFallFlying import EventFallFlying
from .EventDisconnect import EventDisconnect
from .EventInteractBlock import EventInteractBlock
from .EventSendPacket import EventSendPacket
from .EventHeal import EventHeal
from .EventInteractEntity import EventInteractEntity
from .EventBlockUpdate import EventBlockUpdate
from .EventContainerUpdate import EventContainerUpdate
from .EventEntityHealed import EventEntityHealed
from .EventClickSlot import EventClickSlot
from .EventDimensionChange import EventDimensionChange
from .EventItemPickup import EventItemPickup
from .EventQuitGame import EventQuitGame
from .EventOpenScreen import EventOpenScreen
from .EventDeath import EventDeath
from .EventRecvPacket import EventRecvPacket
from .EventAttackEntity import EventAttackEntity
from .EventSignEdit import EventSignEdit
from .EventSendMessage import EventSendMessage
from .CommandContextHelper import CommandContextHelper
from .EventTick import EventTick
from .EventSound import EventSound
from .EventKey import EventKey
from .EventProfileLoad import EventProfileLoad
from .EventService import EventService
from .EventEntityLoad import EventEntityLoad
from .EventChunkUnload import EventChunkUnload
from .EventNameChange import EventNameChange
from .EventArmorChange import EventArmorChange
from .EventPlayerJoin import EventPlayerJoin
from .EventHeldItemChange import EventHeldItemChange

File = TypeVar("java.io.File")




from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .EnchantmentHelper import EnchantmentHelper
from .TextHelper import TextHelper
from .NBTElementHelper import NBTElementHelper
from .BlockHelper import BlockHelper
from .BlockStateHelper import BlockStateHelper
from .CreativeItemStackHelper import CreativeItemStackHelper
from .ItemHelper import ItemHelper
from .BlockPredicateHelper import BlockPredicateHelper

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class ItemStackHelper(BaseHelper):
	"""
	"""

	@overload
	def __init__(self, id: str, count: int) -> None:
		pass

	@overload
	def __init__(self, i: ItemStack) -> None:
		pass

	@overload
	def setDamage(self, damage: int) -> "ItemStackHelper":
		"""Sets the item damage value.
You should use CreativeItemStackHelper#setDamage(int) instead.
You may want to use ItemStackHelper#copy() first.\n
		Since: 1.2.0 

		Args:
			damage: 

		Returns:
			self 
		"""
		pass

	@overload
	def isDamageable(self) -> bool:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def isUnbreakable(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this item is unbreakable, 'false' otherwise. 
		"""
		pass

	@overload
	def isEnchantable(self) -> bool:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def isEnchanted(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the item is enchanted, 'false' otherwise. 
		"""
		pass

	@overload
	def getEnchantments(self) -> List[EnchantmentHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all enchantments on this item. 
		"""
		pass

	@overload
	def getEnchantment(self, id: str) -> EnchantmentHelper:
		"""
		Since: 1.8.4 

		Args:
			id: the id of the enchantment to check for 

		Returns:
			the enchantment instance, containing the level, or 'null' if the item is not
enchanted with the specified enchantment. 
		"""
		pass

	@overload
	def canBeApplied(self, enchantment: EnchantmentHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check for 

		Returns:
			'true' if the specified enchantment can be applied to this item, 'false' otherwise. 
		"""
		pass

	@overload
	def hasEnchantment(self, enchantment: EnchantmentHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the enchantment to check for 

		Returns:
			'true' if the item is enchanted with the specified enchantment of the same
level, 'false' otherwise. 
		"""
		pass

	@overload
	def hasEnchantment(self, enchantment: str) -> bool:
		"""
		Since: 1.8.4 

		Args:
			enchantment: the id of the enchantment to check for 

		Returns:
			'true' if the item is enchanted with the specified enchantment, 'false' otherwise. 
		"""
		pass

	@overload
	def getPossibleEnchantments(self) -> List[EnchantmentHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all enchantments that can be applied to this item. 
		"""
		pass

	@overload
	def getPossibleEnchantmentsFromTable(self) -> List[EnchantmentHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all enchantments that can be applied to this item through an enchanting table. 
		"""
		pass

	@overload
	def getLore(self) -> List[TextHelper]:
		"""The returned list is a copy of the original list and can be modified without affecting the
original item. For editing the actual lore see CreativeItemStackHelper#addLore(java.lang.Object...) .\n
		Since: 1.8.4 

		Returns:
			a list of all lines of lore on this item. 
		"""
		pass

	@overload
	def getMaxDurability(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum durability of this item. 
		"""
		pass

	@overload
	def getDurability(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current durability of this item. 
		"""
		pass

	@overload
	def getRepairCost(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current repair cost of this item. 
		"""
		pass

	@overload
	def getDamage(self) -> int:
		"""

		Returns:
			the damage taken by this item. 
		"""
		pass

	@overload
	def getMaxDamage(self) -> int:
		"""

		Returns:
			the maximum damage this item can take. 
		"""
		pass

	@overload
	def getAttackDamage(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the default attack damage of this item. 
		"""
		pass

	@overload
	def getDefaultName(self) -> TextHelper:
		"""
		Since: 1.2.0 

		Returns:
			was string before 1.6.5 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""

		Returns:
			was string before 1.6.5 
		"""
		pass

	@overload
	def getCount(self) -> int:
		"""

		Returns:
			the item count this stack is holding. 
		"""
		pass

	@overload
	def getMaxCount(self) -> int:
		"""

		Returns:
			the maximum amount of items this stack can hold. 
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""
		Since: 1.1.6, was a String until 1.5.1 
		"""
		pass

	@overload
	def getCreativeTab(self) -> List[TextHelper]:
		"""
		Since: 1.1.3 
		"""
		pass

	@overload
	def getItemID(self) -> str:
		"""
		"""
		pass

	@overload
	def getItemId(self) -> str:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def getTags(self) -> List[str]:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isFood(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isTool(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isWearable(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isEmpty(self) -> bool:
		"""
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def equals(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def equals(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isItemEqual(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isItemEqual(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isItemEqualIgnoreDamage(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isItemEqualIgnoreDamage(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isNBTEqual(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isNBTEqual(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isOnCooldown(self) -> bool:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getCooldownProgress(self) -> float:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def isSuitableFor(self, block: BlockHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			block: the block to check 

		Returns:
			'true' if the given block can be mined and drops when broken with this item, 'false' otherwise. 
		"""
		pass

	@overload
	def isSuitableFor(self, block: BlockStateHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			block: the block to check 

		Returns:
			'true' if the given block can be mined and drops when broken with this item, 'false' otherwise. 
		"""
		pass

	@overload
	def getCreative(self) -> CreativeItemStackHelper:
		"""CreativeItemStackHelper adds methods for manipulating the item's nbt data.\n
		Since: 1.8.4 

		Returns:
			a CreativeItemStackHelper instance for this item. 
		"""
		pass

	@overload
	def getItem(self) -> ItemHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item this stack is made of. 
		"""
		pass

	@overload
	def copy(self) -> "ItemStackHelper":
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def hasDestroyRestrictions(self) -> bool:
		"""This flag only affects players in adventure mode and makes sure only specified blocks can be
destroyed by this item.\n
		Since: 1.8.4 

		Returns:
			'true' if the can destroy flag is set, 'false' otherwise. 
		"""
		pass

	@overload
	def hasPlaceRestrictions(self) -> bool:
		"""This flag only affects players in adventure mode and makes sure this item can only be placed
on specified blocks.\n
		Since: 1.8.4 

		Returns:
			'true' if the can place on flag is set, 'false' otherwise. 
		"""
		pass

	@overload
	def getDestroyRestrictions(self) -> List[BlockPredicateHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all filters set for the can destroy flag. 
		"""
		pass

	@overload
	def getPlaceRestrictions(self) -> List[BlockPredicateHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all filters set for the can place on flag. 
		"""
		pass

	@overload
	def areEnchantmentsHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if enchantments are hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def areModifiersHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if modifiers are hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def isUnbreakableHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the unbreakable flag is hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def isCanDestroyHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the can destroy flag is hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def isCanPlaceHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the can place flag is hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def isDyeHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if dye of colored leather armor is hidden, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .MethodWrapper import MethodWrapper
from .ClassBuilder import ClassBuilder


class ClassBuilder_BodyBuilder:

	@overload
	def appendJavaCode(self, code: str) -> "ClassBuilder_BodyBuilder":
		pass

	@overload
	def appendGuestCode(self, code: MethodWrapper, argsAsObjects: str, tokenBefore: str) -> "ClassBuilder_BodyBuilder":
		"""

		Args:
			code: 
			argsAsObjects: 
			tokenBefore: ie, "return", "Object wasd = " etc 
		"""
		pass

	@overload
	def finish(self) -> "ClassBuilder":
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_decoration_InteractionEntity = TypeVar("net_minecraft_entity_decoration_InteractionEntity")
InteractionEntity = net_minecraft_entity_decoration_InteractionEntity


class InteractionEntityHelper(EntityHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: InteractionEntity) -> None:
		pass

	@overload
	def setCanHit(self, value: bool) -> None:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLastAttacker(self) -> EntityHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getLastInteracted(self) -> EntityHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getWidth(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def getHeight(self) -> float:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def shouldRespond(self) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .StatusEffectHelper import StatusEffectHelper


class EventStatusEffectUpdate(BaseEvent):
	"""
	Since: 1.8.4 
	"""
	oldEffect: StatusEffectHelper
	newEffect: StatusEffectHelper
	added: bool
	removed: bool

	@overload
	def __init__(self, oldEffect: StatusEffectHelper, newEffect: StatusEffectHelper, added: bool) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .ILoomScreen import ILoomScreen


class MixinLoomScreen(ILoomScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_canApplyDyePattern(self) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar

com_neovisionaries_ws_client_WebSocketFrame = TypeVar("com_neovisionaries_ws_client_WebSocketFrame")
WebSocketFrame = com_neovisionaries_ws_client_WebSocketFrame


class Websocket_Disconnected:
	"""
	"""
	serverFrame: WebSocketFrame
	clientFrame: WebSocketFrame
	isServer: bool

	@overload
	def __init__(self, serverFrame: WebSocketFrame, clientFrame: WebSocketFrame, isServer: bool) -> None:
		"""

		Args:
			isServer: 
			clientFrame: 
			serverFrame: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .EventContainer import EventContainer

E = TypeVar("E")
E = E


class FJsMacros_EventAndContext(Generic[E]):
	event: E
	context: EventContainer

	@overload
	def __init__(self, event: E, context: EventContainer) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_decoration_painting_PaintingEntity = TypeVar("net_minecraft_entity_decoration_painting_PaintingEntity")
PaintingEntity = net_minecraft_entity_decoration_painting_PaintingEntity


class PaintingEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PaintingEntity) -> None:
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of this painting. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of this painting. 
		"""
		pass

	@overload
	def getIdentifier(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of this painting's art. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MacroScreen import MacroScreen

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen


class KeyMacrosScreen(MacroScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def keyReleased(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def mouseReleased(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	pass





from typing import overload


class MixinTrueTypeFont:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def modifyWidth(self, w: int, i: int) -> int:
		pass

	@overload
	def modifyHeight(self, h: int, i: int) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_GoatEntity = TypeVar("net_minecraft_entity_passive_GoatEntity")
GoatEntity = net_minecraft_entity_passive_GoatEntity


class GoatEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: GoatEntity) -> None:
		pass

	@overload
	def isScreaming(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this goat is currently screaming, 'false' otherwise. 
		"""
		pass

	@overload
	def hasLeftHorn(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this goat has its left horn still left, 'false' otherwise. 
		"""
		pass

	@overload
	def hasRightHorn(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this goat has its right horn still left, 'false' otherwise. 
		"""
		pass

	@overload
	def hasHorns(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this goat still has a horn, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .History_HistoryStep import History_HistoryStep
from .SelectCursor import SelectCursor


class History_TabLines(History_HistoryStep):

	@overload
	def __init__(self, startLine: int, lineCount: int, reversed: bool, cursor: SelectCursor) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_decoration_Brightness = TypeVar("net_minecraft_entity_decoration_Brightness")
Brightness = net_minecraft_entity_decoration_Brightness

net_minecraft_entity_decoration_DisplayEntity_BillboardMode = TypeVar("net_minecraft_entity_decoration_DisplayEntity_BillboardMode")
DisplayEntity_BillboardMode = net_minecraft_entity_decoration_DisplayEntity_BillboardMode


class MixinDisplayEntity:

	@overload
	def callGetBrightnessUnpacked(self) -> Brightness:
		pass

	@overload
	def callGetViewRange(self) -> float:
		pass

	@overload
	def callGetShadowRadius(self) -> float:
		pass

	@overload
	def callGetShadowStrength(self) -> float:
		pass

	@overload
	def callGetDisplayWidth(self) -> float:
		pass

	@overload
	def callGetGlowColorOverride(self) -> int:
		pass

	@overload
	def callGetDisplayHeight(self) -> float:
		pass

	@overload
	def callGetBillboardMode(self) -> DisplayEntity_BillboardMode:
		pass

	pass





from typing import overload
from typing import List


class Sorting_ServiceSortMethod:
	"""
	Since: 1.8.4 
	"""
	Name: "Sorting_ServiceSortMethod"
	FileName: "Sorting_ServiceSortMethod"
	Enabled: "Sorting_ServiceSortMethod"
	Running: "Sorting_ServiceSortMethod"

	@overload
	def values(self) -> List["Sorting_ServiceSortMethod"]:
		pass

	@overload
	def valueOf(self, name: str) -> "Sorting_ServiceSortMethod":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .BasicFilter import BasicFilter
from .IFilter import IFilter

T = TypeVar("T")

class NotFilter(Generic[T], BasicFilter):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, filter: IFilter) -> None:
		pass

	@overload
	def apply(self, obj: T) -> bool:
		pass

	@overload
	def getFilter(self) -> IFilter:
		pass

	pass





from typing import overload
from .OptionsHelper import OptionsHelper


class OptionsHelper_VideoOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def getFullscreenResolution(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the full screen resolution as a string. 
		"""
		pass

	@overload
	def getBiomeBlendRadius(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current biome blend radius. 
		"""
		pass

	@overload
	def setBiomeBlendRadius(self, radius: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			radius: the new biome blend radius 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getGraphicsMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the selected graphics mode. 
		"""
		pass

	@overload
	def setGraphicsMode(self, mode: str) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the graphics mode to select. Must be either "fast", "fancy" or "fabulous" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChunkBuilderMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the selected chunk builder mode. 
		"""
		pass

	@overload
	def setChunkBuilderMode(self, mode: str) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the chunk builder mode to select. Must be either "none", "nearby" or
            "player_affected" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSmoothLightningMode(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			the selected smooth lightning mode. 
		"""
		pass

	@overload
	def setSmoothLightningMode(self, mode: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the smooth lightning mode to select. boolean value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRenderDistance(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current render distance in chunks. 
		"""
		pass

	@overload
	def setRenderDistance(self, radius: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			radius: the new render distance in chunks 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSimulationDistance(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current simulation distance in chunks. 
		"""
		pass

	@overload
	def setSimulationDistance(self, radius: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			radius: the new simulation distance in chunks 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMaxFps(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current upper fps limit. 
		"""
		pass

	@overload
	def setMaxFps(self, maxFps: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			maxFps: the new maximum fps limit 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isVsyncEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if vsync is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableVsync(self, val: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable vsync or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isViewBobbingEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if view bobbing is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableViewBobbing(self, val: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable view bobbing or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getGuiScale(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current gui scale. 
		"""
		pass

	@overload
	def setGuiScale(self, scale: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			scale: the gui scale to set. Must be 1, 2, 3 or 4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAttackIndicatorType(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current attack indicator type. 
		"""
		pass

	@overload
	def setAttackIndicatorType(self, type: str) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			type: the attack indicator type. Must be either "off", "crosshair", or "hotbar" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getGamma(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current gamma value. 
		"""
		pass

	@overload
	def setGamma(self, gamma: float) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			gamma: the new gamma value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBrightness(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current brightness value. 
		"""
		pass

	@overload
	def setBrightness(self, gamma: float) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			gamma: the new brightness value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getCloudsMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current cloud rendering mode. 
		"""
		pass

	@overload
	def setCloudsMode(self, mode: str) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the cloud rendering mode to select. Must be either "off", "fast" or "fancy" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isFullscreen(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the game is running in fullscreen mode, 'false' otherwise. 
		"""
		pass

	@overload
	def setFullScreen(self, fullscreen: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			fullscreen: whether to enable fullscreen mode or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getParticleMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current particle rendering mode. 
		"""
		pass

	@overload
	def setParticleMode(self, mode: str) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the particle rendering mode to select. Must be either "minimal", "decreased"
            or "all" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMipMapLevels(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current mip map level. 
		"""
		pass

	@overload
	def setMipMapLevels(self, val: int) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new mip map level 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areEntityShadowsEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if entity shadows should be rendered, 'false' otherwise. 
		"""
		pass

	@overload
	def enableEntityShadows(self, val: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable entity shadows or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getDistortionEffect(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current distortion effect scale. 
		"""
		pass

	@overload
	def setDistortionEffects(self, val: float) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new distortion effect scale 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getEntityDistance(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current entity render distance. 
		"""
		pass

	@overload
	def setEntityDistance(self, val: float) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new entity render distance 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getFovEffects(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current fov value. 
		"""
		pass

	@overload
	def setFovEffects(self, val: float) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new fov value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isAutosaveIndicatorEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the autosave indicator is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableAutosaveIndicator(self, val: bool) -> "OptionsHelper_VideoOptionsHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation

T = TypeVar("T")
java_lang_StackTraceElement = TypeVar("java_lang_StackTraceElement")
StackTraceElement = java_lang_StackTraceElement


class BaseWrappedException(Generic[T]):
	stackFrame: T
	location: BaseWrappedException_SourceLocation
	message: str
	next: "BaseWrappedException"

	@overload
	def __init__(self, exception: T, message: str, location: BaseWrappedException_SourceLocation, next: "BaseWrappedException") -> None:
		pass

	@overload
	def wrapHostElement(self, t: StackTraceElement, next: "BaseWrappedException") -> "BaseWrappedException":
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .TextHelper import TextHelper

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class EventTitle(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	type: str
	message: TextHelper

	@overload
	def __init__(self, type: str, message: Text) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .BaseLibrary import BaseLibrary
from .BaseScriptContext import BaseScriptContext


class PerExecLibrary(BaseLibrary):

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .ICategoryTreeParent import ICategoryTreeParent
from .MultiElementContainer import MultiElementContainer
from .Scrollbar import Scrollbar
from .Button import Button

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class CategoryTreeContainer(ICategoryTreeParent, MultiElementContainer):
	category: str
	scroll: Scrollbar
	children: Mapping[str, "CategoryTreeContainer"]
	expandBtn: Button
	showBtn: Button
	isHead: bool
	topScroll: int
	btnHeight: int

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: ICategoryTreeParent) -> None:
		pass

	@overload
	def addCategory(self, category: List[str]) -> "CategoryTreeContainer":
		pass

	@overload
	def selectCategory(self, category: List[str]) -> None:
		pass

	@overload
	def updateOffsets(self) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class MixinDisconnectedScreen:

	@overload
	def getReason(self) -> Text:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .Pos3D import Pos3D

net_minecraft_util_math_Direction = TypeVar("net_minecraft_util_math_Direction")
Direction = net_minecraft_util_math_Direction


class DirectionHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: Direction) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this direction. 
		"""
		pass

	@overload
	def getAxis(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the axis this direction is aligned to. 
		"""
		pass

	@overload
	def isVertical(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this direction is vertical, 'false' otherwise. 
		"""
		pass

	@overload
	def isHorizontal(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this direction is horizontal, 'false' otherwise. 
		"""
		pass

	@overload
	def isTowardsPositive(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this direction is pointing in a positive direction, 'false' otherwise. 
		"""
		pass

	@overload
	def getYaw(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the yaw of this direction. 
		"""
		pass

	@overload
	def getPitch(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the pitch of this direction. 
		"""
		pass

	@overload
	def getOpposite(self) -> "DirectionHelper":
		"""
		Since: 1.8.4 

		Returns:
			the opposite direction. 
		"""
		pass

	@overload
	def getLeft(self) -> "DirectionHelper":
		"""
		Since: 1.8.4 

		Returns:
			the direction to the left. 
		"""
		pass

	@overload
	def getRight(self) -> "DirectionHelper":
		"""
		Since: 1.8.4 

		Returns:
			the direction to the right. 
		"""
		pass

	@overload
	def getVector(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the direction as a directional vector. 
		"""
		pass

	@overload
	def pointsTo(self, yaw: float) -> bool:
		"""
		Since: 1.8.4 

		Args:
			yaw: the yaw to check 

		Returns:
			'true' if the yaw is facing this direction more than any other one, 'false' otherwise. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .OptionsHelper import OptionsHelper


class OptionsHelper_AccessibilityOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def getNarratorMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current narrator mode. 
		"""
		pass

	@overload
	def setNarratorMode(self, mode: str) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the mode to set the narrator to. Must be either "OFF", "ALL", "CHAT", or
            "SYSTEM" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areSubtitlesShown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if subtitles are enabled. 
		"""
		pass

	@overload
	def showSubtitles(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to show subtitles or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setTextBackgroundOpacity(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new opacity for the text background 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getTextBackgroundOpacity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the opacity of the text background. 
		"""
		pass

	@overload
	def isBackgroundForChatOnly(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def enableBackgroundForChatOnly(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatOpacity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat opacity. 
		"""
		pass

	@overload
	def setChatOpacity(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat opacity 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatLineSpacing(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat line spacing. 
		"""
		pass

	@overload
	def setChatLineSpacing(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat line spacing 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatDelay(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat delay in seconds. 
		"""
		pass

	@overload
	def setChatDelay(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat delay in seconds 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isAutoJumpEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if auto jump is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableAutoJump(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable auto jump or not or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isSneakTogglingEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the toggle functionality for sneaking is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleSneak(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable or disable the toggle functionality for sneaking 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isSprintTogglingEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the toggle functionality for sprinting is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleSprint(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable or disable the toggle functionality for sprinting 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getDistortionEffect(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current distortion effect scale. 
		"""
		pass

	@overload
	def setDistortionEffect(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new distortion effect scale 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getFovEffect(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current fov effect scale. 
		"""
		pass

	@overload
	def setFovEffect(self, val: float) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new fov effect scale 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isMonochromeLogoEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the monochrome logo is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def enableMonochromeLogo(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable the monochrome logo or not 

		Returns:
			the current helper instance for chaining. 
		"""
		pass

	@overload
	def areLightningFlashesHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if lighting flashes are hidden, 'false' otherwise. 
		"""
		pass

	@overload
	def setFovEffect(self, val: bool) -> "OptionsHelper_AccessibilityOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new fov value 

		Returns:
			self for chaining. 
		"""
		pass

	pass


